% average promoter state approximation model of NF-kB - iKBa interractions.
%
% INPUTS
%
% A, B, C: values of parameters A, B and C
% p: parameters (should be loaded from 'params.mat')
% nbs: number of observed transcription factor binding sites
% scenario: linear = 0, allornone = 1 or singular = 2
% plot_on: 0 (no plotting) or 1 (plotting)
%
% OUTPUTS
%
% Nn: nuclear NF-kb concentrations in each time step of simulation
% oscillates: 0-NO, 1-YES
% freq: oscillation frequency
% amplitude: oscillation amplitude
% spikiness: oscillation spikiness
function [oscillates, freq, period, amplitude, spikiness] = modelAvg (A, B, C, p, nbs, scenario, plot_on)

% species
X = zeros (1, p.steps); % nuclear NF-kB
Y = zeros (1, p.steps); % IkB mRNA	
Z = zeros (1, p.steps); % IkB 

for i = 2 : p.steps
    
	sNn = p.Ntot * X(i-1);
	
	% multiple binding site part
	w = sNn / p.Kd;	
	n_occ = nbs * w / (1+w);
	
	%%%%%%%%%%
	% linear %
	%%%%%%%%%%
	if (scenario == 0)
		prom_act = n_occ/nbs;
    %%%%%%%%%%%%%%%
	% all or none %
	%%%%%%%%%%%%%%%
    elseif (scenario == 1)
      prom_act = power(n_occ/nbs,nbs);
    else
	%%%%%%%%%%%%
	% singular %
	%%%%%%%%%%%%
        prom_act = 1;
        if (n_occ < 1)
            prom_act = n_occ;
        end;
	end;
	
	%changes
	dX = A * (1-X(i-1)) * p.epsilon / (p.epsilon+Z(i-1))- B*Z(i-1)*X(i-1) / (p.delta + X(i-1));
	dY = prom_act - Y(i-1);
	dZ = Y(i-1) - C * (1-X(i-1))*Z(i-1)*p.epsilon/(p.epsilon + Z(i-1));
	
	% apply the changes
	X(i) = X(i-1) + dX * p.dTau;
	Y(i) = Y(i-1) + dY * p.dTau;
	Z(i) = Z(i-1) + dZ * p.dTau;	
end;


T=0: p.dt : p.t_end - p.dt;



Nn = p.Ntot * X;
Im = (p.kt * p.Ptot * Y) / p.gamma_m;
I = (Z * p.kt * p.ktl * p.Ptot) / power (p.gamma_m, 2);

[oscillates, freq, period, amplitude, spikiness] = measureOsc (Nn, p.dt, p.threshold);

if (plot_on == 1)

	tit = strcat('AVG: MBS NORM; NBS = ',int2str(nbs));
	if (scenario == 0)
		tit = strcat(tit,', linear');
	else if (scenario == 1)
			tit = strcat(tit,', all or none');
		else
			tit = strcat(tit,', singular');
		end;
	 end;

	lab = strcat('A = ', num2str(A),', B = ', num2str(B),', C = ', num2str(C));

	figure((nbs-1)*2+401)
	plot(T,X,T,Z,T,Y);
	legend('Nn','I','Im');
	xlabel(lab);
 
	
	title(tit);
	
	
end;

end