% analysis of different IKK concentrations given the promoter expression scenario, number of interpolation points for IKK concentrations and number of observed transcription factor binding sites
%
% INPUTS
%
% tuneParams: which parameters to vary (ignored in IKK analysis)
% scenarioString: 'linear', 'allornone' or 'singular'
% points: number of interpolation points for IKK concentrations
% nbs: number of observed transcription factor binding sites
function simulateForBSRangeIKK (tuneParams, scenarioString, points, nbs)

    runs = length(nbs) * points;
    
     switch scenarioString
        case 'linear'
            scenario = 0;
        case 'allornone'
            scenario = 1;
        case 'singular'
            scenario = 2;
    end

    % ===========
    % LOAD PARAMS
    % ===========
	params = load ('params.mat');
    
	IKK = linspace (0, 1, points);
    alpha 	= 1.05 * IKK; % degradation rate of IkB in IkB:NF-kb complex
	C = alpha*params.Ntot/(params.gamma_m * params.KI);
	
	paramA = params.A;
	paramB = params.B;
	paramC = C;
    
    % A vector containing no. of oscillatory solutions for different NBS
    num_oscillatory = zeros (1 : length(nbs));
    
    % ===============
	% RUN SIMULATIONS
	% ===============
   
	
	% Simulation results vectors
	[oscillations, periods, freqs, amplitudes, spikiness] = deal (zeros((length(nbs)),points));
    oscillating = 0; % counter of oscillatory solutions 
       
	
    for i = 1 : length (nbs) 
        for j = 1 : points
			[oscillates, freq, period, amplitude, spik] = modelAvg (paramA, paramB, paramC(j), params, nbs(i), scenario,0);	
            if (oscillates)
				periods (i,j) = period;
				amplitudes(i,j) = amplitude;
                oscillations(i,j) = oscillates;
				spikiness(i,j) = spik;
                %freqs(j,k) = freq;
                oscillating = oscillating + 1;
            end;
        end;     
		num_oscillatory(i) = oscillating;
	end;    
    
        
	plot_results (nbs, periods, amplitudes, spikiness, oscillating, IKK);
       
    
    % ----------------------------------------------------------------------------------
    
    % ============
    % PLOT Results
    % ============   
    function plot_results (nbsites, per, amp, spik, oscillating, IKK)
	
	
		nbsites
		IKK
	
        results = figure;
        surf (nbsites, IKK, (per/60)','EdgeColor','none'); 
        axis ([nbsites(1) nbsites(end) IKK(1) IKK(end)]);
        title ([scenarioString ' - Average + Periods (h)']);
        xlabel ('#BS');
        ylabel ('IKK');
        view (0,90);
        caxis([0, 5])
		colorbar;
        colormap;		
        saveas (results, [num2str(scenario) 'periods.png']); 
       
     
		
		
		results = figure;
        surf (nbsites, IKK, amp','EdgeColor','none'); 
        axis ([nbsites(1) nbsites(end) IKK(1) IKK(end)]);
        title ([scenarioString ' - Average + Amplitudes (uM)']);
        xlabel ('#BS');
        ylabel ('IKK');
        view (0,90);
        caxis([0, 1])
		colorbar;
        colormap;		
        saveas (results, [num2str(scenario) 'amplitudes.png']); 
     
		results = figure;
        surf (nbsites, IKK, spik','EdgeColor','none'); 
        axis ([nbsites(1) nbsites(end) IKK(1) IKK(end)]);
        title ([scenarioString ' - Average + Spikiness']);
        xlabel ('#BS');
        ylabel ('IKK');
        view (0,90);
        caxis([0, 5])
		colorbar;
        colormap;		
        saveas (results, [num2str(scenario) 'spikiness.png']); 
       		
		
    end
	
end
 