% analysis of different parameter ranges given the promoter expression scenario, number of interpolation points for IKK concentrations and number of observed transcription factor binding sites
%
% INPUTS
%
% tuneParams: which parameters to vary ('AB', 'AC' or 'BC')
% scenarioString: 'linear', 'allornone' or 'singular'
% points: number of interpolation points for each parameter
% nbs: number of observed transcription factor binding sites
function simulateForBSRangeParams (tuneParams, scenarioString, points, nbs)

    runs = points * points;
       	
    switch scenarioString
        case 'linear'
            scenario = 0;
        case 'allornone'
            scenario = 1;
        case 'singular'
            scenario = 2;
    end

    % ===========
    % LOAD PARAMS
    % ===========
	params = load ('params.mat');
    
   	a = logspace (params.a_min, params.a_max, points);
    b = logspace (params.b_min, params.b_max, points);
    c = logspace (params.c_min, params.c_max, points);
    
	% Choose appropriate combination of params to vary for simulation
    switch tuneParams
        case 'AB'
            paramA = params.A * a; paramB = params.B * b; paramC = params.C;
			param1 = a; p1String = 'A *';
            param2 = b; p2String = 'B *';
        case 'AC'
            paramA = params.A * a; paramB = params.B; paramC = params.C *c;
			param1 = a; p1String = 'A *';
            param2 = c; p2String = 'C *' ;            
        case 'BC'
            paramA = params.A; paramB = params.B * b; paramC = params.C * c;
			param1 = b; p1String = 'B *';
            param2 = c; p2String = 'C *';        
    end
 
    % A vector containing no. of oscillatory solutions for different NBS
    num_oscillatory = zeros (1 : length(nbs));
    
    % ===============
	% RUN SIMULATIONS
	% ===============
    
    for i = 1 : length (nbs) 
        % Simulation results vectors
        [oscillations, periods, freqs, amplitudes, spikiness] = deal (zeros (points, points));
        oscillating = 0; % counter of oscillatory solutions 
        
       if tuneParams == 'AB' 
           for j = 1 : points
               for k = 1 : points
				    [oscillates, freq, period, amplitude, spik] = modelAvg(paramA(j), paramB(k), paramC, params, nbs(i), scenario,0);	
                    if (oscillates)
                        periods (j,k) = period;
						amplitudes(j,k) = amplitude;
                        oscillations(j,k) = oscillates;
						spikiness(j,k) = spik;
                        oscillating = oscillating + 1;
                    end
                end;
            end; 
       elseif tuneParams == 'AC'
           for j = 1 : points
               for k = 1 : points
                    [oscillates, freq, period, amplitude, spik] = modelAvg(paramA(j), paramB(k), paramC, params, nbs(i), scenario,0);	
                    if (oscillates)
                        periods (j,k) = period;
						amplitudes(j,k) = amplitude;
                        oscillations(j,k) = oscillates;
						spikiness(j,k) = spik;
                        oscillating = oscillating + 1;
                    end
                end;
            end; 
       else
           for j = 1 : points
               for k = 1 : points
					[oscillates, freq, period, amplitude, spik] = modelAvg(paramA(j), paramB(k), paramC, params, nbs(i), scenario,0);	
                    if (oscillates)
                        periods (j,k) = period;
						amplitudes(j,k) = amplitude;
                        oscillations(j,k) = oscillates;
						spikiness(j,k) = spik;
                        oscillating = oscillating + 1;
                    end
                end;
            end; 
       end
        
        oscillating
        num_oscillatory(i) = oscillating;
        
        plot_results (nbs(i), periods, amplitudes, spikiness, oscillating, param1, param2);
    end
    
    
    % ============
    % PLOT Results
    % ============   
    function plot_results (nbsites, resMatrix1, resMatrix2, resMatrix3, oscillating, param1, param2)
        results = figure;
        
        surf (param2, param1, resMatrix1/60,'EdgeColor','none'); 
        axis ([param2(1) param2(end) param1(1) param1(end)]);
        title ([num2str(nbsites) 'BS ' scenarioString ' - Average + Periods (h)']);
        xlabel (p2String);
        ylabel (p1String);
        view (0,90);
        legend(['Oscillating: ' num2str(oscillating)],'Location','northoutside','Orientation','horizontal')
        set (gca, 'YScale', 'log', 'XScale', 'log');
		caxis([0, 5])
		colorbar;
        colormap;
        
        saveas (results, [num2str(nbsites) 'periods.png']); 
        
		
		results = figure;
		surf (param2, param1, resMatrix2,'EdgeColor','none'); 
        axis ([param2(1) param2(end) param1(1) param1(end)]);
        title ([num2str(nbsites) 'BS ' scenarioString ' - Average + Amplitudes (uM)']);
        xlabel (p2String);
        ylabel (p1String);
        view (0,90);
        legend(['Oscillating: ' num2str(oscillating)],'Location','northoutside','Orientation','horizontal')
        set (gca, 'YScale', 'log', 'XScale', 'log');
		caxis([0, 1])
        colorbar;
        colormap;
    	
        saveas (results, [num2str(nbsites) 'amplitudes.png']); 
        
		
		results = figure;
		surf (param2, param1, resMatrix3,'EdgeColor','none'); 
        axis ([param2(1) param2(end) param1(1) param1(end)]);
        title ([num2str(nbsites) 'BS ' scenarioString ' - Average + Spikiness']);
        xlabel (p2String);
        ylabel (p1String);
        view (0,90);
        legend(['Oscillating: ' num2str(oscillating)],'Location','northoutside','Orientation','horizontal')
        set (gca, 'YScale', 'log', 'XScale', 'log');
		caxis([0, 5])
        colorbar;
        colormap;
    	
        saveas (results, [num2str(nbsites) 'spikiness.png']); 
        
		
    end
    
   
end
    
